You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by ju...@apache.org on 2010/03/16 18:34:39 UTC

svn commit: r923890 - in /subversion/trunk/subversion: include/svn_wc.h libsvn_wc/props.h libsvn_wc/workqueue.c

Author: julianfoad
Date: Tue Mar 16 17:34:38 2010
New Revision: 923890

URL: http://svn.apache.org/viewvc?rev=923890&view=rev
Log:
Doc strings.

* subversion/include/svn_wc.h
  (svn_wc_get_prop_diffs2): Remove unhelpful verbiage.

* subversion/libsvn_wc/props.h
  (svn_wc__internal_propdiff, svn_wc__internal_propget,
   svn_wc__internal_propset): Give us a clue.
  (svn_wc__marked_as_binary): Add a doc string.

* subversion/libsvn_wc/workqueue.c
  (log_do_committed): Tweak and add comments.

Modified:
    subversion/trunk/subversion/include/svn_wc.h
    subversion/trunk/subversion/libsvn_wc/props.h
    subversion/trunk/subversion/libsvn_wc/workqueue.c

Modified: subversion/trunk/subversion/include/svn_wc.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_wc.h?rev=923890&r1=923889&r2=923890&view=diff
==============================================================================
--- subversion/trunk/subversion/include/svn_wc.h (original)
+++ subversion/trunk/subversion/include/svn_wc.h Tue Mar 16 17:34:38 2010
@@ -6118,8 +6118,7 @@ svn_wc_diff(svn_wc_adm_access_t *anchor,
  * If @a original_props is non-@c NULL, then set @a *original_props to
  * hashtable (<tt>const char *name</tt> -> <tt>const svn_string_t *value</tt>)
  * that represents the 'pristine' property list of @a path.  This hashtable is
- * allocated in @a result_pool, and can be used to compare old and new values
- * of properties.
+ * allocated in @a result_pool.
  *
  * Use @a scratch_pool for temporary allocations.
  */

Modified: subversion/trunk/subversion/libsvn_wc/props.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/props.h?rev=923890&r1=923889&r2=923890&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/props.h (original)
+++ subversion/trunk/subversion/libsvn_wc/props.h Tue Mar 16 17:34:38 2010
@@ -52,7 +52,7 @@ svn_error_t *svn_wc__has_props(svn_boole
                                apr_pool_t *pool);
 
 
-/* Internal function for diffing props. */
+/* Internal function for diffing props. See svn_wc_get_prop_diffs2(). */
 svn_error_t *
 svn_wc__internal_propdiff(apr_array_header_t **propchanges,
                           apr_hash_t **original_props,
@@ -62,7 +62,7 @@ svn_wc__internal_propdiff(apr_array_head
                           apr_pool_t *scratch_pool);
 
 
-/* Internal function for fetching a property.  */
+/* Internal function for fetching a property. See svn_wc_prop_get2(). */
 svn_error_t *
 svn_wc__internal_propget(const svn_string_t **value,
                          svn_wc__db_t *db,
@@ -72,7 +72,7 @@ svn_wc__internal_propget(const svn_strin
                          apr_pool_t *scratch_pool);
 
 
-/* Internal function for setting a property.  */
+/* Internal function for setting a property. See svn_wc_prop_set4(). */
 svn_error_t *
 svn_wc__internal_propset(svn_wc__db_t *db,
                          const char *local_abspath,
@@ -221,6 +221,9 @@ svn_wc__load_revert_props(apr_hash_t **r
                           apr_pool_t *result_pool,
                           apr_pool_t *scratch_pool);
 
+/* Set *MARKED to indicate whether the versioned file at LOCAL_ABSPATH in DB
+ * has a "binary" file type, as indicated by its working svn:mime-type
+ * property. See svn_mime_type_is_binary() for the interpretation. */
 svn_error_t *
 svn_wc__marked_as_binary(svn_boolean_t *marked,
                          const char *local_abspath,

Modified: subversion/trunk/subversion/libsvn_wc/workqueue.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/workqueue.c?rev=923890&r1=923889&r2=923890&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/workqueue.c (original)
+++ subversion/trunk/subversion/libsvn_wc/workqueue.c Tue Mar 16 17:34:38 2010
@@ -1247,9 +1247,11 @@ log_do_committed(svn_wc__db_t *db,
 
   /*** Mark the committed item committed-to-date ***/
 
-  /* If "this dir" has been replaced (delete + add), all its
-     immmediate children *must* be either scheduled for deletion (they
-     were children of "this dir" during the "delete" phase of its
+  /* If "this dir" has been replaced (delete + add), remove those of
+     its children that are marked for deletion.
+
+     All its immmediate children *must* be either scheduled for deletion
+     (they were children of "this dir" during the "delete" phase of its
      replacement), added (they are new children of the replaced dir),
      or replaced (they are new children of the replace dir that have
      the same names as children that were present during the "delete"
@@ -1306,20 +1308,21 @@ log_do_committed(svn_wc__db_t *db,
         }
     }
 
+  /* Install the node's current working props as its new base props.
+   * Remember some details about the prop changes, for later use. */
   SVN_ERR(svn_wc__props_modified(&prop_mods, db, local_abspath, pool));
   if (prop_mods)
     {
       if (orig_entry->kind == svn_node_file)
         {
           /* Examine propchanges here before installing the new
-             propbase.  If the executable prop was -deleted-, then
-             tell install_committed_file() so.
-
-             The same applies to the needs-lock property. */
+             propbase.  If the executable prop was -deleted-, remember
+             this by setting REMOVE_EXECUTABLE so that we can later
+             tell install_committed_file() so.  The same applies to the
+             needs-lock property, remembered by setting SET_READ_WRITE. */
           int i;
           apr_array_header_t *propchanges;
 
-
           SVN_ERR(svn_wc__internal_propdiff(&propchanges, NULL, db,
                                             local_abspath, pool, pool));
           for (i = 0; i < propchanges->nelts; i++)
@@ -1336,9 +1339,11 @@ log_do_committed(svn_wc__db_t *db,
             }
         }
 
+      /* Install LOCAL_ABSPATHs working props as base props. */
       SVN_ERR(svn_wc__working_props_committed(db, local_abspath, pool));
-  }
+    }
 
+  /* If it's a file, install the tree changes and the file's text. */
   if (orig_entry->kind == svn_node_file)
     {
       svn_boolean_t overwrote_working;
@@ -1446,6 +1451,8 @@ log_do_committed(svn_wc__db_t *db,
                                 pool));
     }
 
+  /* It's not a file, so it's a directory. */
+
   SVN_ERR(svn_wc__db_global_commit(db, local_abspath,
                                    new_revision, new_date, new_author,
                                    NULL /* new_checksum */,